# BibTeX HowTo & style guide

Dieses Dokument dient dazu das Format von BibTeX-Einträgen für den Lehrstuhl für
Kommunikationsnetze an der Universität Tübingen zu beschreiben und zu
standardisieren.

## PDF für Paper suchen

Am besten verwendet man hierzu Google mit folgender Suchanfrage:

```
"<Titel>" filetype:pdf
```

die Anführungszeichen sind hier wichtig und `<Titel>` muss durch den Titel des
entsprechenden Papers ersetzt werden, z. B.:

```
"P4NFV: An NFV Architecture with Flexible Data Plane Reconfiguration" filetype:pdf
```

## Syntax / coding style

Es ist sehr wichtig, dass die Klammern, Kommas, etc. richtig gesetzt sind!
Da solche Fehler sehr schnell übersehen werden ist es sehr sinnvoll die BibTeX
Dateien einmal selber zu kompilieren bevor man sie Professor Menth oder einem
Mitarbeiter schickt.

**Strings**: Wenn die Groß-/Kleinschreibung übernommen werden soll müssen zwei
geschweifte Klammern (`{{...}}`) verwendet werden, ansonsten nur eine
geschweifte Klammer (`{...}`).

**Umlaute**: Umlaute in BibTeX-Einträgen müssen ersetzt werden, da sie sonst
evtl. nicht richtig dargestellt werden (seit TeX Live 2018 sollten alle Tools
standardmäßig UTF-8 unterstützen, jedoch wird es noch einige Zeit dauern bis
jede Linux-Distribution diese Version hat). Ein `ü` muss dazu beispielsweise
durch `{\"u}` ersetzt werden und ein `ß` durch `{\ss}`.

**Einrückung (optional)**: Zwei Leerzeichen pro Ebene.

**Zeilenlänge (optional)**: Nach Möglichkeit Zeilen auf 80 Zeichen beschränken.
Werden mehrere Zeilen benötigt, so sollen diese um eine weitere Ebene eingerückt
werden (d. h. zwei Leerzeichen mehr als in der ursprünglichen Zeile).

Bitte unnötige Leerzeichen am Ende von Zeilen vermeiden.

## Beispiel (article)

```bibtex
@article{DoDo17,
  author    = {Jane Doe and John Doe and M. Mustermann},
  title     = {{A Standard for the Transmission of IP Datagrams on Avian
    Carriers with Quality of Service}},
  journal   = CL,
  volume    = 42,
  number    = 1,
  month     = jan,
  year      = 2017,
  pages     = {24--42}
}
```

### Name des Eintrags

```bibtex
@article{DoDo17,
```

**Do, Do**: Jeweils die zwei Anfangsbuchstaben der Nachnamen von den ersten zwei
Autoren des Papers. Gibt es nur einen Autor so können die ersten vier
Buchstaben verwendet werden oder bis zu sechs Buchstaben wenn der Nachname dann
ausgeschrieben werden kann. Sonderzeichen müssen hier ersetzt werden, z. B. `ü`
durch `u` (hier nicht `ue`). Kommt es zu einer Kollision wird `b` (`c`, `d`,
etc.) als Suffix angehängt (z. B. `DoDo17b`).

**17**: Die letzten zwei Ziffern vom Jahr in dem das Paper veröffentlicht wurde.

### Author

```bibtex
  author    = {Jane Doe and John Doe and M. Mustermann},
```

Hier werden alle Autoren in der Reihenfolgen in der sie auf dem Paper erscheinen
aufgelistet. Die einzelnen Namen (jeweils `Vorname [weitere Vornamen] Nachname`)
werden dabei mit dem Keyword ` and ` abgetrennt. Kommas innerhalb der Klammern
(z. B. `Nachname, Vorname`) sollten vermieden werden, da dies gerne zu
Problemen führt. Sofern bekannt sollten immer die vollständigen Vornamen der
Autoren angegeben werden, sind jedoch nur die Anfangsbuchstaben bekannt ist dies
nicht weiter schlimm, da die Vornamen nach dem Kompilieren sowieso auf die
Anfangsbuchstaben abgekürzt werden.

### Title

```bibtex
  title     = {{A Standard for the Transmission of IP Datagrams on Avian
    Carriers with Quality of Service}},
```

Titel des Papers (case-sensitive, sollte direkt vom Paper übernommen werden).
Der Titel soll großgeschrieben werden, auch wenn er auf dem Paper mit einem
Kleinbuchstaben anfängt.

### Daten zur Veröffentlichung

```bibtex
  journal   = CL,
  volume    = 42,
  number    = 1,
  month     = jan,
  year      = 2017,
  pages     = {24--42}
```

**journal**: Nach Möglichkeit eine vordefinierte Abkürzung verwenden (siehe
`Literature.bib`), ansonsten: `{{Some Journal}}`. In diesem Fall wurde folgende
vordefinierte Abkürzung aus der `Literature.bib` verwendet:
```bibtex
@STRING{CL={{IEEE} Communications Letters}}
```

**volume**: Sollte eine Nummer sein.

**number**: Ist optional und entspricht der "Issue" Angabe (ebenfalls eine
Nummer).

**month**: Die ersten drei Buchstaben (lower-case) des Monats in dem das Journal
veröffentlicht wurde (kann von der Veröffentlichung des Papers abweichen).

**year**: Das Jahr in dem das Journal veröffentlicht wurde (Nummer aus vier
Zahlen).

**pages**: `{}` falls nicht angegeben/bekannt, ansonsten eine per `--` (keine
Leerzeichen) getrennte "Range" oder eine einzelne Nummer (z. B. `pages=42`).

Wenn "volume" und "pages" noch nicht bekannt sind kann bei den "IEEE
Communications Letters" z. B. folgender Platzhalter verwendet werden:

```bibtex
  volume    = {{PP}},
  number    = 99,
  pages     = {}
```

## Weitere Beispiele

```bibtex
@inproceedings{HeBa18,
  author    = {Mu He and Arsany Basta and Andreas Blenk and Nemanja Deric and
    Wolfgang Kellerer},
  title     = {{P4NFV: An NFV Architecture with Flexible Data Plane
    Reconfiguration}},
  booktitle = CNSM,
  year      = 2018
}

@misc{iproute2,
  title={{iproute2}},
  howpublished={\url{https://wiki.linuxfoundation.org/networking/iproute2}},
  author={{Alexey Kuznetsov}}
}

@misc{OpenWrt,
  title={{OpenWrt}},
  howpublished={\url{https://openwrt.org/}},
  author={{OpenWrt Project}}
}

@techreport{rfc6835,
  author={D. Farinacci and D. Meyer},
  title={{The Locator/ID Separation Protocol Internet Groper (LIG)}},
  howpublished={Internet Requests for Comments},
  type={{RFC}},
  number=6835,
  pages={1-12},
  year={2013},
  month={January},
  issn={2070-1721},
  publisher={{RFC Editor}},
  institution={{RFC Editor}},
  url={https://www.rfc-editor.org/rfc/rfc6835.txt}
}
```

## Übersicht über die verschiedenen Literaturtypen

- https://de.wikipedia.org/wiki/BibTeX#Literaturtypen_(Entry_Types)
- https://en.wikipedia.org/wiki/BibTeX#Entry_types
